@@ -9,16 +9,14 @@
 require "rbconfig"
 
 module Gem
-  VERSION = "3.7.2"
+  VERSION = "4.0.4"
 end
 
-# Must be first since it unloads the prelude from 1.9.2
-require_relative "rubygems/compatibility"
-
 require_relative "rubygems/defaults"
 require_relative "rubygems/deprecate"
 require_relative "rubygems/errors"
 require_relative "rubygems/target_rbconfig"
+require_relative "rubygems/win_platform"
 
 ##
 # RubyGems is the Ruby standard for publishing and managing third party
@@ -39,7 +37,7 @@ require_relative "rubygems/target_rbconfig"
 # Further RubyGems documentation can be found at:
 #
 # * {RubyGems Guides}[https://guides.rubygems.org]
-# * {RubyGems API}[https://www.rubydoc.info/github/rubygems/rubygems] (also available from
+# * {RubyGems API}[https://www.rubydoc.info/github/ruby/rubygems] (also available from
 #   <tt>gem server</tt>)
 #
 # == RubyGems Plugins
@@ -71,7 +69,7 @@ require_relative "rubygems/target_rbconfig"
 # == Bugs
 #
 # You can submit bugs to the
-# {RubyGems bug tracker}[https://github.com/rubygems/rubygems/issues]
+# {RubyGems bug tracker}[https://github.com/ruby/rubygems/issues]
 # on GitHub
 #
 # == Credits
@@ -107,7 +105,7 @@ require_relative "rubygems/target_rbconfig"
 #
 # == License
 #
-# See {LICENSE.txt}[https://github.com/rubygems/rubygems/blob/master/LICENSE.txt] for permissions.
+# See {LICENSE.txt}[https://github.com/ruby/rubygems/blob/master/LICENSE.txt] for permissions.
 #
 # Thanks!
 #
@@ -116,18 +114,6 @@ require_relative "rubygems/target_rbconfig"
 module Gem
   RUBYGEMS_DIR = __dir__
 
-  ##
-  # An Array of Regexps that match windows Ruby platforms.
-
-  WIN_PATTERNS = [
-    /bccwin/i,
-    /cygwin/i,
-    /djgpp/i,
-    /mingw/i,
-    /mswin/i,
-    /wince/i,
-  ].freeze
-
   GEM_DEP_FILES = %w[
     gem.deps.rb
     gems.rb
@@ -163,8 +149,6 @@ module Gem
 
   DEFAULT_SOURCE_DATE_EPOCH = 315_619_200
 
-  @@win_platform = nil
-
   @configuration = nil
   @gemdeps = nil
   @loaded_specs = {}
@@ -227,7 +211,7 @@ module Gem
     finish_resolve rs
   end
 
-  def self.finish_resolve(request_set=Gem::RequestSet.new)
+  def self.finish_resolve(request_set = Gem::RequestSet.new)
     request_set.import Gem::Specification.unresolved_deps.values
     request_set.import Gem.loaded_specs.values.map {|s| Gem::Dependency.new(s.name, s.version) }
 
@@ -303,7 +287,7 @@ module Gem
       # RubyGems now uses this new `Gem.activate_and_load_bin_path` helper in
       # binstubs, which is of course not overridden in Bundler since it didn't
       # exist at the time. So, include the override here to workaround that.
-      load ENV["BUNDLE_BIN_PATH"] if ENV["BUNDLE_BIN_PATH"] && spec.version <= "2.5.22"
+      load ENV["BUNDLE_BIN_PATH"] if ENV["BUNDLE_BIN_PATH"] && spec.version <= Gem::Version.create("2.5.22")
 
       # Make sure there's no version of Bundler in `$LOAD_PATH` that's different
       # from the version we just activated. If that was the case (it happens
@@ -344,7 +328,7 @@ module Gem
   ##
   # The path where gem executables are to be installed.
 
-  def self.bindir(install_dir=Gem.dir)
+  def self.bindir(install_dir = Gem.dir)
     return File.join install_dir, "bin" unless
       install_dir.to_s == Gem.default_dir.to_s
     Gem.default_bindir
@@ -353,7 +337,7 @@ module Gem
   ##
   # The path were rubygems plugins are to be installed.
 
-  def self.plugindir(install_dir=Gem.dir)
+  def self.plugindir(install_dir = Gem.dir)
     File.join install_dir, "plugins"
   end
 
@@ -537,7 +521,7 @@ An Array (#{env.inspect}) was passed in from #{caller[3]}
   # Note that find_files will return all files even if they are from different
   # versions of the same gem.  See also find_latest_files
 
-  def self.find_files(glob, check_load_path=true)
+  def self.find_files(glob, check_load_path = true)
     files = []
 
     files = find_files_from_load_path glob if check_load_path
@@ -574,7 +558,7 @@ An Array (#{env.inspect}) was passed in from #{caller[3]}
   # Unlike find_files, find_latest_files will return only files from the
   # latest version of a gem.
 
-  def self.find_latest_files(glob, check_load_path=true)
+  def self.find_latest_files(glob, check_load_path = true)
     files = []
 
     files = find_files_from_load_path glob if check_load_path
@@ -682,7 +666,7 @@ An Array (#{env.inspect}) was passed in from #{caller[3]}
   # warnings in platform constants
 
   def self.load_bundler_extensions(version)
-    return unless version <= "2.6.9"
+    return unless version <= Gem::Version.create("2.6.9")
 
     previous_platforms = {}
 
@@ -1094,18 +1078,6 @@ An Array (#{env.inspect}) was passed in from #{caller[3]}
     self.paths = hash
   end
 
-  ##
-  # Is this a windows platform?
-
-  def self.win_platform?
-    if @@win_platform.nil?
-      ruby_platform = RbConfig::CONFIG["host_os"]
-      @@win_platform = !WIN_PATTERNS.find {|r| ruby_platform =~ r }.nil?
-    end
-
-    @@win_platform
-  end
-
   ##
   # Is this a java platform?
 
