@@ -8,7 +8,6 @@
 
 require_relative "installer_uninstaller_utils"
 require_relative "exceptions"
-require_relative "deprecate"
 require_relative "package"
 require_relative "ext"
 require_relative "user_interaction"
@@ -27,8 +26,6 @@ require_relative "user_interaction"
 # file.  See Gem.pre_install and Gem.post_install for details.
 
 class Gem::Installer
-  extend Gem::Deprecate
-
   ##
   # Paths where env(1) might live.  Some systems are broken and have it in
   # /bin
@@ -67,23 +64,6 @@ class Gem::Installer
   attr_reader :package
 
   class << self
-    #
-    # Changes in rubygems to lazily loading `rubygems/command` (in order to
-    # lazily load `optparse` as a side effect) affect bundler's custom installer
-    # which uses `Gem::Command` without requiring it (up until bundler 2.2.29).
-    # This hook is to compensate for that missing require.
-    #
-    # TODO: Remove when rubygems no longer supports running on bundler older
-    # than 2.2.29.
-
-    def inherited(klass)
-      if klass.name == "Bundler::RubyGemsGemInstaller"
-        require "rubygems/command"
-      end
-
-      super(klass)
-    end
-
     ##
     # Overrides the executable format.
     #
@@ -170,7 +150,7 @@ class Gem::Installer
   #               process. If not set, then Gem::Command.build_args is used
   # :post_install_message:: Print gem post install message if true
 
-  def initialize(package, options={})
+  def initialize(package, options = {})
     require "fileutils"
 
     @options = options
@@ -291,11 +271,7 @@ class Gem::Installer
     run_pre_install_hooks
 
     # Set loaded_from to ensure extension_dir is correct
-    if @options[:install_as_default]
-      spec.loaded_from = default_spec_file
-    else
-      spec.loaded_from = spec_file
-    end
+    spec.loaded_from = spec_file
 
     # Completely remove any previous gem files
     FileUtils.rm_rf gem_dir
@@ -304,24 +280,17 @@ class Gem::Installer
     dir_mode = options[:dir_mode]
     FileUtils.mkdir_p gem_dir, mode: dir_mode && 0o755
 
-    if @options[:install_as_default]
-      extract_bin
-      write_default_spec
-    else
-      extract_files
+    extract_files
 
-      build_extensions
-      write_build_info_file
-      run_post_build_hooks
-    end
+    build_extensions
+    write_build_info_file
+    run_post_build_hooks
 
     generate_bin
     generate_plugins
 
-    unless @options[:install_as_default]
-      write_spec
-      write_cache_file
-    end
+    write_spec
+    write_cache_file
 
     File.chmod(dir_mode, gem_dir) if dir_mode
 
@@ -409,15 +378,6 @@ class Gem::Installer
     !dependency.matching_specs.empty?
   end
 
-  ##
-  # Unpacks the gem into the given directory.
-
-  def unpack(directory)
-    @gem_dir = directory
-    extract_files
-  end
-  rubygems_deprecate :unpack
-
   ##
   # The location of the spec file that is installed.
   #
@@ -426,12 +386,18 @@ class Gem::Installer
     File.join gem_home, "specifications", "#{spec.full_name}.gemspec"
   end
 
+  def default_spec_dir
+    dir = File.join(gem_home, "specifications", "default")
+    FileUtils.mkdir_p dir
+    dir
+  end
+
   ##
   # The location of the default spec file for default gems.
   #
 
   def default_spec_file
-    File.join gem_home, "specifications", "default", "#{spec.full_name}.gemspec"
+    File.join default_spec_dir, "#{spec.full_name}.gemspec"
   end
 
   ##
@@ -669,6 +635,7 @@ class Gem::Installer
     @build_root          = options[:build_root]
 
     @build_args = options[:build_args]
+    @build_jobs = options[:build_jobs]
 
     @gem_home = @install_dir || user_install_dir || Gem.dir
 
@@ -837,7 +804,7 @@ class Gem::Installer
   # configure scripts and rakefiles or mkrf_conf files.
 
   def build_extensions
-    builder = Gem::Ext::Builder.new spec, build_args, Gem.target_rbconfig
+    builder = Gem::Ext::Builder.new spec, build_args, Gem.target_rbconfig, build_jobs
 
     builder.build_extensions
   end
@@ -906,11 +873,7 @@ class Gem::Installer
 
     ensure_loadable_spec
 
-    if options[:install_as_default]
-      Gem.ensure_default_gem_subdirectories gem_home
-    else
-      Gem.ensure_gem_subdirectories gem_home
-    end
+    Gem.ensure_gem_subdirectories gem_home
 
     return true if @force
 
@@ -979,6 +942,15 @@ class Gem::Installer
                     end
   end
 
+  def build_jobs
+    @build_jobs ||= begin
+                      require "etc"
+                      Etc.nprocessors + 1
+                    rescue LoadError
+                      1
+                    end
+  end
+
   def rb_config
     Gem.target_rbconfig
   end
